# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageStatisticsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkLabelOverlapMeasuresImageFilterPython
else:
    import _itkLabelOverlapMeasuresImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageSinkPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImageRegionPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImagePython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageToImageFilterCommonPython

def itkLabelOverlapMeasuresImageFilterISS2_New():
    return itkLabelOverlapMeasuresImageFilterISS2.New()

class itkLabelOverlapMeasuresImageFilterISS2(itk.itkImageSinkPython.itkImageSinkISS2):
    r"""Proxy of C++ itkLabelOverlapMeasuresImageFilterISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelOverlapMeasuresImageFilterISS2_Pointer"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelOverlapMeasuresImageFilterISS2_Pointer"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_Clone(self)

    def SetTargetImage(self, _arg):
        r"""
        SetTargetImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_SetTargetImage(self, _arg)

    def GetTargetImage(self):
        r"""GetTargetImage(self) -> itkImageSS2"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_GetTargetImage(self)

    def SetSourceImage(self, _arg):
        r"""
        SetSourceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_SetSourceImage(self, _arg)

    def GetSourceImage(self):
        r"""GetSourceImage(self) -> itkImageSS2"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_GetSourceImage(self)

    def GetLabelSetMeasures(self):
        r"""GetLabelSetMeasures(self) -> std::unordered_map< short,itkLabelOverlapMeasuresImageFilterISS2::LabelSetMeasures >"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_GetLabelSetMeasures(self)

    def GetTotalOverlap(self):
        r"""GetTotalOverlap(self) -> double"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_GetTotalOverlap(self)

    def GetTargetOverlap(self, arg0):
        r"""
        GetTargetOverlap(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_GetTargetOverlap(self, arg0)

    def GetUnionOverlap(self, *args):
        r"""
        GetUnionOverlap(self) -> double
        GetUnionOverlap(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_GetUnionOverlap(self, *args)

    def GetJaccardCoefficient(self, *args):
        r"""
        GetJaccardCoefficient(self) -> double
        GetJaccardCoefficient(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_GetJaccardCoefficient(self, *args)

    def GetMeanOverlap(self, *args):
        r"""
        GetMeanOverlap(self) -> double
        GetMeanOverlap(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_GetMeanOverlap(self, *args)

    def GetDiceCoefficient(self, *args):
        r"""
        GetDiceCoefficient(self) -> double
        GetDiceCoefficient(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_GetDiceCoefficient(self, *args)

    def GetVolumeSimilarity(self, *args):
        r"""
        GetVolumeSimilarity(self) -> double
        GetVolumeSimilarity(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_GetVolumeSimilarity(self, *args)

    def GetFalseNegativeError(self, *args):
        r"""
        GetFalseNegativeError(self) -> double
        GetFalseNegativeError(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_GetFalseNegativeError(self, *args)

    def GetFalsePositiveError(self, *args):
        r"""
        GetFalsePositiveError(self) -> double
        GetFalsePositiveError(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_GetFalsePositiveError(self, *args)

    def GetFalseDiscoveryRate(self, *args):
        r"""
        GetFalseDiscoveryRate(self) -> double
        GetFalseDiscoveryRate(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_GetFalseDiscoveryRate(self, *args)
    Input1HasNumericTraitsCheck = _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_Input1HasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelOverlapMeasuresImageFilterPython.delete_itkLabelOverlapMeasuresImageFilterISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelOverlapMeasuresImageFilterISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelOverlapMeasuresImageFilterISS2

        Create a new object of the class itkLabelOverlapMeasuresImageFilterISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelOverlapMeasuresImageFilterISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelOverlapMeasuresImageFilterISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelOverlapMeasuresImageFilterISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelOverlapMeasuresImageFilterISS2 in _itkLabelOverlapMeasuresImageFilterPython:
_itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS2_swigregister(itkLabelOverlapMeasuresImageFilterISS2)

def itkLabelOverlapMeasuresImageFilterISS3_New():
    return itkLabelOverlapMeasuresImageFilterISS3.New()

class itkLabelOverlapMeasuresImageFilterISS3(itk.itkImageSinkPython.itkImageSinkISS3):
    r"""Proxy of C++ itkLabelOverlapMeasuresImageFilterISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelOverlapMeasuresImageFilterISS3_Pointer"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelOverlapMeasuresImageFilterISS3_Pointer"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_Clone(self)

    def SetTargetImage(self, _arg):
        r"""
        SetTargetImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_SetTargetImage(self, _arg)

    def GetTargetImage(self):
        r"""GetTargetImage(self) -> itkImageSS3"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_GetTargetImage(self)

    def SetSourceImage(self, _arg):
        r"""
        SetSourceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_SetSourceImage(self, _arg)

    def GetSourceImage(self):
        r"""GetSourceImage(self) -> itkImageSS3"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_GetSourceImage(self)

    def GetLabelSetMeasures(self):
        r"""GetLabelSetMeasures(self) -> std::unordered_map< short,itkLabelOverlapMeasuresImageFilterISS3::LabelSetMeasures >"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_GetLabelSetMeasures(self)

    def GetTotalOverlap(self):
        r"""GetTotalOverlap(self) -> double"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_GetTotalOverlap(self)

    def GetTargetOverlap(self, arg0):
        r"""
        GetTargetOverlap(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_GetTargetOverlap(self, arg0)

    def GetUnionOverlap(self, *args):
        r"""
        GetUnionOverlap(self) -> double
        GetUnionOverlap(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_GetUnionOverlap(self, *args)

    def GetJaccardCoefficient(self, *args):
        r"""
        GetJaccardCoefficient(self) -> double
        GetJaccardCoefficient(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_GetJaccardCoefficient(self, *args)

    def GetMeanOverlap(self, *args):
        r"""
        GetMeanOverlap(self) -> double
        GetMeanOverlap(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_GetMeanOverlap(self, *args)

    def GetDiceCoefficient(self, *args):
        r"""
        GetDiceCoefficient(self) -> double
        GetDiceCoefficient(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_GetDiceCoefficient(self, *args)

    def GetVolumeSimilarity(self, *args):
        r"""
        GetVolumeSimilarity(self) -> double
        GetVolumeSimilarity(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_GetVolumeSimilarity(self, *args)

    def GetFalseNegativeError(self, *args):
        r"""
        GetFalseNegativeError(self) -> double
        GetFalseNegativeError(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_GetFalseNegativeError(self, *args)

    def GetFalsePositiveError(self, *args):
        r"""
        GetFalsePositiveError(self) -> double
        GetFalsePositiveError(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_GetFalsePositiveError(self, *args)

    def GetFalseDiscoveryRate(self, *args):
        r"""
        GetFalseDiscoveryRate(self) -> double
        GetFalseDiscoveryRate(self, arg0) -> double

        Parameters
        ----------
        arg0: short

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_GetFalseDiscoveryRate(self, *args)
    Input1HasNumericTraitsCheck = _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_Input1HasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelOverlapMeasuresImageFilterPython.delete_itkLabelOverlapMeasuresImageFilterISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelOverlapMeasuresImageFilterISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelOverlapMeasuresImageFilterISS3

        Create a new object of the class itkLabelOverlapMeasuresImageFilterISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelOverlapMeasuresImageFilterISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelOverlapMeasuresImageFilterISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelOverlapMeasuresImageFilterISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelOverlapMeasuresImageFilterISS3 in _itkLabelOverlapMeasuresImageFilterPython:
_itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterISS3_swigregister(itkLabelOverlapMeasuresImageFilterISS3)

def itkLabelOverlapMeasuresImageFilterIUC2_New():
    return itkLabelOverlapMeasuresImageFilterIUC2.New()

class itkLabelOverlapMeasuresImageFilterIUC2(itk.itkImageSinkPython.itkImageSinkIUC2):
    r"""Proxy of C++ itkLabelOverlapMeasuresImageFilterIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelOverlapMeasuresImageFilterIUC2_Pointer"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelOverlapMeasuresImageFilterIUC2_Pointer"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_Clone(self)

    def SetTargetImage(self, _arg):
        r"""
        SetTargetImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_SetTargetImage(self, _arg)

    def GetTargetImage(self):
        r"""GetTargetImage(self) -> itkImageUC2"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_GetTargetImage(self)

    def SetSourceImage(self, _arg):
        r"""
        SetSourceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_SetSourceImage(self, _arg)

    def GetSourceImage(self):
        r"""GetSourceImage(self) -> itkImageUC2"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_GetSourceImage(self)

    def GetLabelSetMeasures(self):
        r"""GetLabelSetMeasures(self) -> std::unordered_map< unsigned char,itkLabelOverlapMeasuresImageFilterIUC2::LabelSetMeasures >"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_GetLabelSetMeasures(self)

    def GetTotalOverlap(self):
        r"""GetTotalOverlap(self) -> double"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_GetTotalOverlap(self)

    def GetTargetOverlap(self, arg0):
        r"""
        GetTargetOverlap(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_GetTargetOverlap(self, arg0)

    def GetUnionOverlap(self, *args):
        r"""
        GetUnionOverlap(self) -> double
        GetUnionOverlap(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_GetUnionOverlap(self, *args)

    def GetJaccardCoefficient(self, *args):
        r"""
        GetJaccardCoefficient(self) -> double
        GetJaccardCoefficient(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_GetJaccardCoefficient(self, *args)

    def GetMeanOverlap(self, *args):
        r"""
        GetMeanOverlap(self) -> double
        GetMeanOverlap(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_GetMeanOverlap(self, *args)

    def GetDiceCoefficient(self, *args):
        r"""
        GetDiceCoefficient(self) -> double
        GetDiceCoefficient(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_GetDiceCoefficient(self, *args)

    def GetVolumeSimilarity(self, *args):
        r"""
        GetVolumeSimilarity(self) -> double
        GetVolumeSimilarity(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_GetVolumeSimilarity(self, *args)

    def GetFalseNegativeError(self, *args):
        r"""
        GetFalseNegativeError(self) -> double
        GetFalseNegativeError(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_GetFalseNegativeError(self, *args)

    def GetFalsePositiveError(self, *args):
        r"""
        GetFalsePositiveError(self) -> double
        GetFalsePositiveError(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_GetFalsePositiveError(self, *args)

    def GetFalseDiscoveryRate(self, *args):
        r"""
        GetFalseDiscoveryRate(self) -> double
        GetFalseDiscoveryRate(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_GetFalseDiscoveryRate(self, *args)
    Input1HasNumericTraitsCheck = _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_Input1HasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelOverlapMeasuresImageFilterPython.delete_itkLabelOverlapMeasuresImageFilterIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelOverlapMeasuresImageFilterIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelOverlapMeasuresImageFilterIUC2

        Create a new object of the class itkLabelOverlapMeasuresImageFilterIUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelOverlapMeasuresImageFilterIUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelOverlapMeasuresImageFilterIUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelOverlapMeasuresImageFilterIUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelOverlapMeasuresImageFilterIUC2 in _itkLabelOverlapMeasuresImageFilterPython:
_itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC2_swigregister(itkLabelOverlapMeasuresImageFilterIUC2)

def itkLabelOverlapMeasuresImageFilterIUC3_New():
    return itkLabelOverlapMeasuresImageFilterIUC3.New()

class itkLabelOverlapMeasuresImageFilterIUC3(itk.itkImageSinkPython.itkImageSinkIUC3):
    r"""Proxy of C++ itkLabelOverlapMeasuresImageFilterIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelOverlapMeasuresImageFilterIUC3_Pointer"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelOverlapMeasuresImageFilterIUC3_Pointer"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_Clone(self)

    def SetTargetImage(self, _arg):
        r"""
        SetTargetImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_SetTargetImage(self, _arg)

    def GetTargetImage(self):
        r"""GetTargetImage(self) -> itkImageUC3"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_GetTargetImage(self)

    def SetSourceImage(self, _arg):
        r"""
        SetSourceImage(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_SetSourceImage(self, _arg)

    def GetSourceImage(self):
        r"""GetSourceImage(self) -> itkImageUC3"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_GetSourceImage(self)

    def GetLabelSetMeasures(self):
        r"""GetLabelSetMeasures(self) -> std::unordered_map< unsigned char,itkLabelOverlapMeasuresImageFilterIUC3::LabelSetMeasures >"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_GetLabelSetMeasures(self)

    def GetTotalOverlap(self):
        r"""GetTotalOverlap(self) -> double"""
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_GetTotalOverlap(self)

    def GetTargetOverlap(self, arg0):
        r"""
        GetTargetOverlap(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_GetTargetOverlap(self, arg0)

    def GetUnionOverlap(self, *args):
        r"""
        GetUnionOverlap(self) -> double
        GetUnionOverlap(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_GetUnionOverlap(self, *args)

    def GetJaccardCoefficient(self, *args):
        r"""
        GetJaccardCoefficient(self) -> double
        GetJaccardCoefficient(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_GetJaccardCoefficient(self, *args)

    def GetMeanOverlap(self, *args):
        r"""
        GetMeanOverlap(self) -> double
        GetMeanOverlap(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_GetMeanOverlap(self, *args)

    def GetDiceCoefficient(self, *args):
        r"""
        GetDiceCoefficient(self) -> double
        GetDiceCoefficient(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_GetDiceCoefficient(self, *args)

    def GetVolumeSimilarity(self, *args):
        r"""
        GetVolumeSimilarity(self) -> double
        GetVolumeSimilarity(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_GetVolumeSimilarity(self, *args)

    def GetFalseNegativeError(self, *args):
        r"""
        GetFalseNegativeError(self) -> double
        GetFalseNegativeError(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_GetFalseNegativeError(self, *args)

    def GetFalsePositiveError(self, *args):
        r"""
        GetFalsePositiveError(self) -> double
        GetFalsePositiveError(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_GetFalsePositiveError(self, *args)

    def GetFalseDiscoveryRate(self, *args):
        r"""
        GetFalseDiscoveryRate(self) -> double
        GetFalseDiscoveryRate(self, arg0) -> double

        Parameters
        ----------
        arg0: unsigned char

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_GetFalseDiscoveryRate(self, *args)
    Input1HasNumericTraitsCheck = _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_Input1HasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelOverlapMeasuresImageFilterPython.delete_itkLabelOverlapMeasuresImageFilterIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelOverlapMeasuresImageFilterIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelOverlapMeasuresImageFilterIUC3

        Create a new object of the class itkLabelOverlapMeasuresImageFilterIUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelOverlapMeasuresImageFilterIUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelOverlapMeasuresImageFilterIUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelOverlapMeasuresImageFilterIUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelOverlapMeasuresImageFilterIUC3 in _itkLabelOverlapMeasuresImageFilterPython:
_itkLabelOverlapMeasuresImageFilterPython.itkLabelOverlapMeasuresImageFilterIUC3_swigregister(itkLabelOverlapMeasuresImageFilterIUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def label_overlap_measures_image_filter(*args: itkt.ImageLike,  target_image: itkt.Image=..., source_image: itkt.Image=...,**kwargs):
    """Functional interface for LabelOverlapMeasuresImageFilter"""
    import itk

    kwarg_typehints = { 'target_image':target_image,'source_image':source_image }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.LabelOverlapMeasuresImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def label_overlap_measures_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageStatistics.LabelOverlapMeasuresImageFilter
    label_overlap_measures_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    label_overlap_measures_image_filter.__doc__ = filter_object.__doc__



